@@ -78,6 +78,11 @@ class ImazuPacket(ABC):
         self.state_value = packet[8: -2]
         self.checksum = packet[-2:-1]
 
+    @property
+    def packet_id(self) -> str:
+        """Packet Id"""
+        return f'{self.device.value}_{self.sub}'
+
     @property
     def name(self) -> str:
         """Name"""
@@ -149,7 +154,6 @@ class ImazuPacket(ABC):
     @abstractmethod
     def make_scan(self) -> bytearray:
         """Scan packet Make"""
-        pass
 
     def make_change(self, value_type: ValueType, change_value: int) -> bytearray:
         """Change packet Make"""
@@ -514,18 +518,18 @@ def parse_packet(packet: str) -> list[ImazuPacket]:
     def _parse_imazu_packet() -> Optional[ImazuPacket]:
         """Imazu packet Parse"""
         device = packets[3]
-#        if device == '16':
-#            return GuardPacket(packets)
+        #        if device == '16':
+        #            return GuardPacket(packets)
         if device == '18':
             return ThermostatPacket(packets)
         if device == '19':
             return LightPacket(packets)
-#        if device == '1a':
-#            return DimmingPacket(packets)
+        #        if device == '1a':
+        #            return DimmingPacket(packets)
         if device == '1b':
             return GasPacket(packets)
-#        if device == '1c':
-#            return AcPacket(packets)
+        #        if device == '1c':
+        #            return AcPacket(packets)
         if device == '1f':
             return OutletPacket(packets)
         if device == '2a':
